@@ -1,5 +1,5 @@
 
-/* $Id: memmap_win32.c,v 1.6 2004/03/07 10:54:37 hio Exp $ */
+/* $Id: memmap_win32.c,v 1.7 2005/05/15 08:34:42 hio Exp $ */
 
 #include "Japanese.h"
 #include <windows.h>
@@ -45,20 +45,20 @@ BOOL APIENTRY DllMain( HANDLE hDll,
 #endif
 
   /* SJIS <=> UTF8 Ѵơ֥ */
-  unsigned short const* g_u2s_table;
-  unsigned long  const* g_s2u_table;
+  UJ_UINT16 const* g_u2s_table;
+  UJ_UINT32 const* g_s2u_table;
 
   /* i-mode/j-sky/dot-iʸ <=> UTF8 Ѵơ֥ */
-  unsigned long  const* g_ei2u1_table;
-  unsigned long  const* g_ei2u2_table;
-  unsigned short const* g_eu2i1_table;
-  unsigned short const* g_eu2i2_table;
-  unsigned long  const* g_ej2u1_table;
-  unsigned long  const* g_ej2u2_table;
-  unsigned char  const* g_eu2j1_table; /* char [][5] */
-  unsigned char  const* g_eu2j2_table; /* char [][5] */
-  unsigned long  const* g_ed2u_table;
-  unsigned short const* g_eu2d_table;
+  UJ_UINT32 const* g_ei2u1_table;
+  UJ_UINT32 const* g_ei2u2_table;
+  UJ_UINT16 const* g_eu2i1_table;
+  UJ_UINT16 const* g_eu2i2_table;
+  UJ_UINT32 const* g_ej2u1_table;
+  UJ_UINT32 const* g_ej2u2_table;
+  UJ_UINT8  const* g_eu2j1_table; /* char [][5] */
+  UJ_UINT8  const* g_eu2j2_table; /* char [][5] */
+  UJ_UINT32 const* g_ed2u_table;
+  UJ_UINT16 const* g_eu2d_table;
 
   /* i-mode/j-sky/dot-iʸ <=> UTF8 Ѵơ֥ǿ */
   /* ХȿǤʤǿ                                   */
@@ -184,33 +184,33 @@ do_memmap(void)
   }
 
   /* u2s,s2u */
-  g_u2s_table = (unsigned short*)(g_mmap_u2s_start +     0x0);
-  g_s2u_table = (unsigned long *)(g_mmap_u2s_start + 0x20000);
+  g_u2s_table = (UJ_UINT16*)(g_mmap_u2s_start +     0x0);
+  g_s2u_table = (UJ_UINT32*)(g_mmap_u2s_start + 0x20000);
 
   /* i-mode 1 */
-  g_eu2i1_table = (unsigned short*)(g_mmap_emj_start +     0x0); /* +0x2000 */
+  g_eu2i1_table = (UJ_UINT16*)(g_mmap_emj_start +     0x0); /* +0x2000 */
   g_eu2i1_size  = 0x2000/2;
-  g_ei2u1_table = (unsigned long *)(g_mmap_emj_start +  0x2000); /* +0x0800 */
+  g_ei2u1_table = (UJ_UINT32*)(g_mmap_emj_start +  0x2000); /* +0x0800 */
   g_ei2u1_size  = 0x800/4;
   /* i-mode 2 */
-  g_eu2i2_table = (unsigned short*)(g_mmap_emj_start +  0x2800); /* +0x2000 */
+  g_eu2i2_table = (UJ_UINT16*)(g_mmap_emj_start +  0x2800); /* +0x2000 */
   g_eu2i2_size  = 0x2000/2;
-  g_ei2u2_table = (unsigned long *)(g_mmap_emj_start +  0x4800); /* +0x0800 */
+  g_ei2u2_table = (UJ_UINT32*)(g_mmap_emj_start +  0x4800); /* +0x0800 */
   g_ei2u2_size  = 0x800/4;
   /* jsky 1 */
-  g_eu2j1_table = (unsigned char *)(g_mmap_emj_start +  0x5000); /* +0x5000 */
+  g_eu2j1_table = (UJ_UINT8*)(g_mmap_emj_start +  0x5000); /* +0x5000 */
   g_eu2j1_size  = 0x5000/1;
-  g_ej2u1_table = (unsigned long *)(g_mmap_emj_start +  0xa000); /* +0xc00 */
+  g_ej2u1_table = (UJ_UINT32*)(g_mmap_emj_start +  0xa000); /* +0xc00 */
   g_ej2u1_size  = 0xc00/4;
   /* jsky 2 */
-  g_eu2j2_table = (unsigned char *)(g_mmap_emj_start +  0xac00); /* +0x5000 */
+  g_eu2j2_table = (UJ_UINT8*)(g_mmap_emj_start +  0xac00); /* +0x5000 */
   g_eu2j2_size  = 0x5000/1;
-  g_ej2u2_table = (unsigned long *)(g_mmap_emj_start +  0xfc00); /* +0xc00 */
+  g_ej2u2_table = (UJ_UINT32*)(g_mmap_emj_start +  0xfc00); /* +0xc00 */
   g_ej2u2_size  = 0xc00/4;
   /* dot-i */
-  g_eu2d_table  = (unsigned short*)(g_mmap_emj_start + 0x10800); /* +0x2000 */
+  g_eu2d_table  = (UJ_UINT16*)(g_mmap_emj_start + 0x10800); /* +0x2000 */
   g_eu2d_size   = 0x2000/2;
-  g_ed2u_table  = (unsigned long *)(g_mmap_emj_start + 0x12800); /* +0x1400 */
+  g_ed2u_table  = (UJ_UINT32*)(g_mmap_emj_start + 0x12800); /* +0x1400 */
   g_ed2u_size   = 0x1400/4;
 
   return;
